@@ -4,17 +4,20 @@
 ##
 ##    file - Name of the file to read.
 ##
-## $Id: read_file.tcl 1212149 2011-12-08 21:57:35Z mxmanghi $
+## $Id: read_file.tcl 1643517 2014-12-06 10:54:14Z mxmanghi $
 ##
 ###
 
 namespace eval ::rivet {
 
-    proc read_file {file} {
+    proc read_file {file args} {
+
         set fp [open $file]
+        if {[llength $args]} { eval fconfigure $fp $args }
         set x [read $fp]
         close $fp
         return $x
+
     }
 
 }
