@@ -9,7 +9,7 @@
  * 	Common API layer.
  */
 
-/* $Id: TclWeb.h 1647357 2014-12-22 17:35:20Z mxmanghi $ */
+/* $Id: TclWeb.h 1721698 2015-12-26 00:22:11Z mxmanghi $ */
 
 /* Tcl 8.4 migration. */
 #ifndef CONST84
@@ -23,18 +23,6 @@
 #define DEFAULT_HEADER_TYPE "text/html"
 #define DEFAULT_TIME_FORMAT "%A, %d-%b-%Y %H:%M:%S %Z"
 
-typedef struct TclWebRequest {
-    Tcl_Interp*     interp;
-    request_rec*    req;
-    ApacheRequest*  apachereq;
-    ApacheUpload*   upload;
-    int             headers_printed;	/* has the header been printed yet? */
-    int             headers_set;		/* has the header been set yet? */
-    int             content_sent;
-    int             environment_set;	/* have we setup the environment variables? */
-    char*           charset;
-} TclWebRequest;
-
 /* Creates a TclWebRequest object */
 
 TclWebRequest* TclWeb_NewRequestObject (apr_pool_t *p);
@@ -48,7 +36,7 @@ TclWebRequest* TclWeb_NewRequestObject (apr_pool_t *p);
  *-----------------------------------------------------------------------------
  */
 
-int TclWeb_InitRequest(TclWebRequest *req, Tcl_Interp *interp, void *arg);
+int TclWeb_InitRequest(rivet_thread_private* private, Tcl_Interp *interp);
 
 /*
  *-----------------------------------------------------------------------------
@@ -81,7 +69,7 @@ int TclWeb_PrintError(CONST84 char *errstr, int htmlflag, TclWebRequest *req);
  *-----------------------------------------------------------------------------
  */
 
-int TclWeb_HeaderSet(char *header, char *val, TclWebRequest *req);
+int         TclWeb_HeaderSet(char *header, char *val, TclWebRequest *req);
 void        TclWeb_OutputHeaderSet(char *header, char *val, TclWebRequest *req);
 const char* TclWeb_OutputHeaderGet(char *header, TclWebRequest *req);
 
@@ -122,9 +110,9 @@ int TclWeb_GetVarNames(Tcl_Obj *result, int source, TclWebRequest *req);
 
 int TclWeb_GetAllVars(Tcl_Obj *result, int source, TclWebRequest *req);
 
-int TclWeb_GetEnvVars(Tcl_Obj *envvar, TclWebRequest *req);
+int TclWeb_GetEnvVars(Tcl_Obj *envvar, rivet_thread_private *p);
 
-int TclWeb_GetHeaderVars(Tcl_Obj *headersvar, TclWebRequest *req);
+int TclWeb_GetHeaderVars(Tcl_Obj *headersvar, rivet_thread_private *p);
 
 /*
  *-----------------------------------------------------------------------------
@@ -267,7 +255,7 @@ char *TclWeb_StringToUtf(char *in, TclWebRequest *req);
 
 Tcl_Obj * TclWeb_StringToUtfToObj(char *in, TclWebRequest *req);
 
-char *TclWeb_GetEnvVar( TclWebRequest *req, char * );
+char *TclWeb_GetEnvVar(rivet_thread_private *,char *);
 
 char *TclWeb_GetVirtualFile( TclWebRequest *req, char *virtualname );
 
