@@ -26,6 +26,12 @@
 
 #include <tcl.h>
 #include <string.h>
+/* Function prototypes are defined with EXTERN. Since we are in the same DLL,
+ * no need to keep this extern... */
+#ifdef EXTERN
+#   undef EXTERN
+#   define EXTERN
+#endif /* EXTERN */
 #include "rivet.h"
 
 static Tcl_ObjCmdProc Rivet_LremoveObjCmd;
@@ -500,24 +506,24 @@ TCL_CMD_HEADER( Rivet_LassignArrayObjCmd )
     varValue = (listIdx < listObjc) ?
         listObjv[listIdx] : Tcl_NewStringObj("", -1);
 
-    if( Tcl_ObjSetVar2( interp, objv[2], objv[idx],
-                varValue, TCL_LEAVE_ERR_MSG ) == NULL ) {
-        return TCL_ERROR;
+    if (Tcl_ObjSetVar2( interp, objv[2], objv[idx],
+                varValue, TCL_LEAVE_ERR_MSG ) == NULL) {
+            return TCL_ERROR;
         }
     }
 
     /* We have some left over items.  Return them in a list. */
     if( listIdx < listObjc ) {
-    Tcl_Obj *list = Tcl_NewListObj( 0, NULL );
-    int i;
+        Tcl_Obj *list = Tcl_NewListObj( 0, NULL );
+        int i;
 
-    for( i = listIdx; i < listObjc; ++i )
-    {
-        if (Tcl_ListObjAppendElement(interp, list, listObjv[i]) != TCL_OK) {
-        return TCL_ERROR;
+        for( i = listIdx; i < listObjc; ++i )
+        {
+            if (Tcl_ListObjAppendElement(interp, list, listObjv[i]) != TCL_OK) {
+            return TCL_ERROR;
+            }
         }
-    }
-    Tcl_SetObjResult( interp, list );
+        Tcl_SetObjResult( interp, list );
     }
     return TCL_OK;
 }
@@ -544,10 +550,11 @@ extern Tcl_Namespace* Rivet_GetNamespace( Tcl_Interp* interp);
 int 
 Rivet_InitList( Tcl_Interp *interp)
 {
-    RIVET_OBJ_CMD("lremove",Rivet_LremoveObjCmd);
-    RIVET_OBJ_CMD("comma_split",Rivet_CommaSplitObjCmd);
-    RIVET_OBJ_CMD("comma_join",Rivet_CommaJoinObjCmd);
-    RIVET_OBJ_CMD("lassign_array",Rivet_LassignArrayObjCmd);
+    RIVET_OBJ_CMD("lremove",Rivet_LremoveObjCmd,NULL);
+    RIVET_OBJ_CMD("comma_split",Rivet_CommaSplitObjCmd,NULL);
+    RIVET_OBJ_CMD("comma_join",Rivet_CommaJoinObjCmd,NULL);
+    RIVET_OBJ_CMD("lassign_array",Rivet_LassignArrayObjCmd,NULL);
+
 #if RIVET_NAMESPACE_EXPORT == 1
     {
         Tcl_Namespace* rivet_ns = Rivet_GetNamespace(interp);
@@ -557,5 +564,6 @@ Rivet_InitList( Tcl_Interp *interp)
         RIVET_EXPORT_CMD(interp,rivet_ns,"lassign_array");
     }
 #endif
+
     return TCL_OK;
 }
