@@ -1,31 +1,42 @@
 /*
- * -- Rivet parser - Contains functions for loading up Tcl scripts either
- *    in flat Tcl files, or in Rivet .rvt files.
+ * Rivet parser.
+ *
+ * Contains functions for loading up Tcl scripts either in flat Tcl
+ * files, or in Rivet .rvt files.
+ *
  */
 
-/*
-    Licensed to the Apache Software Foundation (ASF) under one
-    or more contributor license agreements.  See the NOTICE file
-    distributed with this work for additional information
-    regarding copyright ownership.  The ASF licenses this file
-    to you under the Apache License, Version 2.0 (the
-    "License"); you may not use this file except in compliance
-    with the License.  You may obtain a copy of the License at
+/* Copyright 2002-2004 The Apache Software Foundation
 
-      http://www.apache.org/licenses/LICENSE-2.0
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
 
-    Unless required by applicable law or agreed to in writing,
-    software distributed under the License is distributed on an
-    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-    KIND, either express or implied.  See the License for the
-    specific language governing permissions and limitations
-    under the License.
+        http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
 */
 
-/* $Id: rivetParser.c 1733936 2016-03-07 15:01:09Z mxmanghi $ */
+/* $Id: rivetParser.c 1813852 2017-10-31 07:17:04Z mxmanghi $ */
+
+/* Rivet config */
+#ifdef HAVE_CONFIG_H
+#include <rivet_config.h>
+#endif
 
 #include <string.h>
 #include <tcl.h>
+
+/* Function prototypes are defined with EXTERN. Since we are in the same DLL,
+ * no need to keep this extern... */
+#ifdef EXTERN
+#   undef EXTERN
+#   define EXTERN
+#endif /* EXTERN */
 #include "rivetParser.h"
 
 int Rivet_Parser(Tcl_Obj *outbuf, Tcl_Obj *inbuf);
@@ -73,6 +84,62 @@ Rivet_GetTclFile(char *filename, Tcl_Obj *outbuf, Tcl_Interp *interp)
     return TCL_OK;
 }
 
+#if RIVET_CORE == mod_rivet_ng
+/*
+ *-----------------------------------------------------------------------------
+ * Rivet_GetRivetFileNG -- 
+ *
+ * The mod_rivet_ng core doesn't assume the parsed script to be 
+ * enclosed in the ::request namespace. The whole ::request lifecycle is
+ * devolved to the Rivet::request_handling procedure
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+int
+Rivet_GetRivetFile(char *filename, Tcl_Obj *outbuf, Tcl_Interp *interp)
+{
+    int sz = 0;
+    Tcl_Obj *inbuf;
+    Tcl_Channel rivetfile;
+
+    /*
+     * we call Tcl to read this file but the caveat exposed in 
+     * in Rivet_GetRivetFile still holds true (TODO)
+     */
+
+    rivetfile = Tcl_OpenFileChannel(interp, filename, "r", 0664);
+    if (rivetfile == NULL) {
+        /* Don't need to adderrorinfo - Tcl_OpenFileChannel takes care
+           of that for us. */
+        return TCL_ERROR;
+    }
+
+    Tcl_AppendToObj(outbuf, "puts -nonewline \"", -1);
+    inbuf = Tcl_NewObj();
+    Tcl_IncrRefCount(inbuf);
+    sz = Tcl_ReadChars(rivetfile, inbuf, -1, 0);
+
+    Tcl_Close(interp, rivetfile);
+    if (sz == -1)
+    {
+        Tcl_AddErrorInfo(interp, Tcl_PosixError(interp));
+        Tcl_DecrRefCount(inbuf);
+        return TCL_ERROR;
+    }
+
+    /* If we are not inside a <? ?> section, add the closing ". */
+    if (Rivet_Parser(outbuf, inbuf) == 0)
+    {
+        Tcl_AppendToObj(outbuf, "\"\n", 2);
+    }
+
+    Tcl_DecrRefCount(inbuf);
+    /* END PARSER  */
+    return TCL_OK;
+}
+
+#else /* traditional rivet file processing with enclosion within the ::request namespace */
 
 /*
  *-----------------------------------------------------------------------------
@@ -146,6 +213,8 @@ Rivet_GetRivetFile(char *filename, int toplevel,
     return TCL_OK;
 }
 
+#endif
+
 /*
  *-----------------------------------------------------------------------------
  *
